@@ -4,7 +4,7 @@ package WebService::Rollbar::Notifier;
 use strict;
 use warnings;
 
-our $VERSION = '1.001002'; # VERSION
+our $VERSION = '1.001003'; # VERSION
 
 use Mojo::Base -base;
 use Mojo::UserAgent;
@@ -67,7 +67,7 @@ sub notify {
         ( $self->callback ? $self->callback : () ),
     );
 
-    return $self->callback ? (1) : $response->res->body;
+    return $self->callback ? (1) : $response;
 }
 
 
@@ -218,13 +218,13 @@ response.
 
     use JSON::MaybeXS;
     $roll->callback(undef);
-    my $json_response = $roll->notify('debug', "Message to send");
-    say decode_json($json_response;);
+    my $response = $roll->notify('debug', "Message to send");
+    say decode_json( $response->res->body );
 
 Takes two mandatory and one optional arguments. Always returns
 true value if we're making non-blocking calls (see
 C<callback> argument to constructor). Otherwise, returns the response
-as JSON I<string>. The arguments are:
+as L<Mojo::Transaction::HTTP> object. The arguments are:
 
 =head3 First argument
 
